==> haskell-base-orphans-0.5.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-base-orphans/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.5.0
id: base-orphans-0.5.0-a13c08e02979420be3bfcfc755842cf4
key: baseo_6r3PnYSweurA3Ul5tUzwvY
license: MIT
copyright: (c) 2012-2015 Simon Hengel,
           (c) 2014 João Cristóvão,
           (c) 2015 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/base-orphans-0.5.0
hs-libraries: HSbase-orphans-0.5.0-6r3PnYSweurA3Ul5tUzwvY
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-orphans-0.5.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-base-orphans/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-orphans
version: 0.5.1
id: base-orphans-0.5.1-066f51369735933a8c1cc4e054dd01ca
key: baseo_6AX85lbMA7QGAoLE1cgr8u
license: MIT
copyright: (c) 2012-2015 Simon Hengel,
           (c) 2014 João Cristóvão,
           (c) 2015 Ryan Scott
maintainer: Simon Hengel <sol@typeful.net>,
            João Cristóvão <jmacristovao@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
homepage: https://github.com/haskell-compat/base-orphans#readme
synopsis: Backwards-compatible orphan instances for base
description:
    @base-orphans@ defines orphan instances that mimic instances available in later versions of @base@ to a wider (older) range of compilers. @base-orphans@ does not export anything except the orphan instances themselves and complements @<http://hackage.haskell.org/package/base-compat base-compat>@.
    See the README for what instances are covered: <https://github.com/haskell-compat/base-orphans#readme>. See also the <https://github.com/haskell-compat/base-orphans#what-is-not-covered what is not covered> section.
category: Compatibility
author: Simon Hengel <sol@typeful.net>,
        João Cristóvão <jmacristovao@gmail.com>,
        Ryan Scott <ryan.gl.scott@gmail.com>
exposed: True
exposed-modules:
    Data.Orphans
hidden-modules: Data.Orphans.Prelude
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/base-orphans-0.5.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/base-orphans-0.5.1
hs-libraries: HSbase-orphans-0.5.1-6AX85lbMA7QGAoLE1cgr8u
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
haddock-interfaces: /usr/share/doc/haskell-base-orphans/html/base-orphans.haddock
haddock-html: /usr/share/doc/haskell-base-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
